===============================
fintie
===============================


.. image:: https://img.shields.io/pypi/v/fintie.svg
        :target: https://pypi.python.org/pypi/fintie

.. image:: https://img.shields.io/travis/qytz/cn_stock_daily.svg
        :target: https://travis-ci.org/qytz/cn_stock_daily

.. image:: https://readthedocs.org/projects/fintie/badge/?version=latest
        :target: https://fintie.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/qytz/cn_stock_daily/shield.svg
     :target: https://pyup.io/repos/github/qytz/cn_stock_daily/
     :alt: Updates


A powerful data tool


* Free software: Apache License 2.0
* Documentation: https://fintie.readthedocs.io.


Features
--------

* 支持异步调用(可与`finchan`结合使用)接口；
* 支持同步调用(研究)接口；
* 支持命令行模式；

使用方法
-----------
见 `使用说明 <https://fintie.readthedocs.io/usage.html>`_
